module Debouncer(
  input      Clock,            // Zegar
  input      Reset,            // 1 - praca, 0 - reset
  input      NoisySignal,      // Sygna z przycisku
  output reg FilteredSignal    // Sygna odfiltrowany
);
  
  parameter  FREQUENCY_MHZ = 10;
  parameter  PERIOD_US     = 100;
  localparam DELAY         = FREQUENCY_MHZ * PERIOD_US;
  localparam WIDTH         = $clog2(DELAY + 1);
  
  reg [WIDTH-1:0] Counter = 0;
  
  always @(posedge Clock, negedge Reset) begin
    if(!Reset) begin
      Counter        <= 0;
      FilteredSignal <= 0;
    end else if(NoisySignal != FilteredSignal && Counter < DELAY) begin
      Counter <= Counter + 1'b1;            // 1
    end else if(Counter == DELAY) begin
      Counter <= 0;                         // 2a
      FilteredSignal <= NoisySignal;        // 2b
    end else begin
      Counter <= 0;                         // 3
    end
  end
  
endmodule
