module top(
	input         Reset,
	input         ButtonUp,
	input         ButtonDown,
	output [6:0] Segments
);
	
	// Generator sygnau zegarowego
	OSCH #(
		.NOM_FREQ("14.00")
	) OSCH_inst(
		.STDBY(1'b0),
		.OSC(Clock14MHz),
		.SEDSTDBY()
	);
	
	// Odszumianie przycisku UP
	wire ButtonUpFiltered;
	Debouncer #(
		.FREQUENCY_MHZ(14),
		.PERIOD_US(1)                          // 2
	) DebounceUp(
		.Clock(Clock14MHz),
		.Reset(Reset),
		.NoisySignal(ButtonUp),
		.FilteredSignal(ButtonUpFiltered)
	);
		
	// Odszumianie przycisku DOWN
	wire ButtonDownFiltered;
	Debouncer #(
		.FREQUENCY_MHZ(14),
		.PERIOD_US(1)                          // 1
	) DebounceDown(
		.Clock(Clock14MHz),
		.Reset(Reset),
		.NoisySignal(ButtonDown),
		.FilteredSignal(ButtonDownFiltered)
	);
	
	// Wykrywanie zbocza rosncego przycisku UP
	wire RequestUp;
	EdgeDetector UpDetector(
		.Clock(Clock14MHz),
		.Reset(Reset),
		.Signal(ButtonUpFiltered),
		.RisingEdge(RequestUp),
		.FallingEdge()
	);
	
	// Wykrywanie zbocza rosncego przycisku DOWN
	wire RequestDown;
	EdgeDetector DownDetector(
		.Clock(Clock14MHz),
		.Reset(Reset),
		.Signal(ButtonDownFiltered),
		.RisingEdge(RequestDown),
		.FallingEdge()
	);
	
	// Licznik
	wire [3:0] CountValue;
	Counter #(
		.WIDTH(4)
	) Counter0(
		.Clock(Clock14MHz),
		.Reset(Reset),
		.CountUp(RequestUp),
		.CountDown(RequestDown),
		.Value(CountValue)
	);
	
	// Dekoder wywietlacza 7-segmentowego
	Decoder7seg #(
		.COMMON_CATHODE(1)
	) Dekoder0(
		.Data(CountValue),
		.Segments(Segments)
	);
	

endmodule
	